function [] = elmfiles( data, nbeam, nint, reference, name, type )
%UNTITLED5 Summary of this function goes here
%   Detailed explanation goes here

fout = fopen(name, 'w');
header(fout);

zr = data(:,1);

    
% Posicin nodos
zn = zr(1) + [0:2*nbeam]'/(2*nbeam)*(zr(end) - zr(1));

%% RIGID BODIES

%Rigid bodies location located at correct integation points +/-
%1/sqrt(3)

%Non-dimensional
zb(1) = 0;
zb(2:2:2*nbeam) = [1:2:2*nbeam] - 1/sqrt(3);
zb(3:2:2*nbeam + 1) = [1:2:2*nbeam] + 1/sqrt(3);
zb(2*nbeam + 2) = 2*nbeam;

%Dimensional
zb = (zr(1) + zb/(2*nbeam)*(zr(end) - zr(1)))';

% Interpolacin
dataRebin = interp1(zr,data,zb);
dbody = dataRebin;
dIz = dbody(:,3) + dbody(:,4);

% Integracin
body_int = zeros(2*nbeam+1,8);
sm = zeros(2*nbeam+1,1);

for i=1:length(body_int(:,1))
    
    for j=2:4
        body_int(i,j) = dbody(i,j)*dbody(i+1,1) - dbody(i+1,j)*dbody(i,1) + ...
            0.5*(dbody(i+1,j)-dbody(i,j))/(dbody(i+1,1)-dbody(i,1)) * ...
            (dbody(i+1,1)^2 - dbody(i,1)^2);
    end
    
    body_int(i,5) = dIz(i,1)*dbody(i+1,1) - dIz(i+1,1)*dbody(i,1) + ...
            0.5*(dIz(i+1,1)-dIz(i,1))/(dbody(i+1,1)-dbody(i,1)) * ...
            (dbody(i+1,1)^2 - dbody(i,1)^2);
    
    % Clculo momento esttico
    sm(i) = 0.5*(dbody(i,2) - (dbody(i+1,2)-dbody(i,2))/(dbody(i+1,1)-dbody(i,1)) * ...
        dbody(i,1))*(dbody(i+1,1)^2 - dbody(i,1)^2) + 1/3*(dbody(i+1,2)-dbody(i,2))/...
        (dbody(i+1,1)-dbody(i,1)) * (dbody(i+1,1)^3 - dbody(i,1)^3);
    
    % Clculo centro de masas
    body_int(i,1) = sm(i) / body_int(i,2);
       
end

if type == 1
    xcg = interp1(zr, data(:,5),body_int(:,1));
    ycg = interp1(zr, data(:,6),body_int(:,1));
    twist = interp1(zr, data(:,end),body_int(:,1));
else
    xcg = zeros(length(body_int(:,1)),1);
    ycg = xcg;
    twist = xcg;
end

for i=1:length(body_int(:,1))
    body_int(i,6) = -xcg(i);    %x
    body_int(i,7) = -ycg(i);    %y
    body_int(i,8) = twist(i)*pi/180; %twist
end

% Exportar resultados de slidos rgidos
for i=1:length(body_int(:,1))

    fprintf(fout, 'body: %s + %d, %s + %d,\n',reference, i-1,reference, i-1);
    fprintf(fout, '        %+15.8e,\n', body_int(i,2));
    fprintf(fout, '        reference, %s,\n', reference);

    fprintf(fout, '                %+15.8e, %+15.8e, %+15.8e,\n',...
        cos(body_int(i,8))*body_int(i,6) - sin(body_int(i,8))*body_int(i,7),...
        sin(body_int(i,8))*body_int(i,6) + cos(body_int(i,8))*body_int(i,7),...
        body_int(i,1));
    fprintf(fout, '        diag,\n');
    fprintf(fout, '                %+15.8e, %+15.8e, %+15.8e,\n',...
        body_int(i,3), body_int(i,4), body_int(i,5));

    fprintf(fout, '        inertial, reference, %s,\n', reference);
    fprintf(fout, '                1, %+15.8e, %+15.8e, %+15.8e,\n',...
        cos(body_int(i,8)), -sin(body_int(i,8)), 0.);
    fprintf(fout, '                3, %+15.8e, %+15.8e, %+15.8e;\n',...
        0., 0., 1.);
    
end

fprintf(fout, '# total mass: %.3f\n', sum(body_int(:,2)));
fprintf(fout, 'inertia: %s + 0,\n', reference); 
fprintf(fout, '        position, reference, %s, null,\n', reference);
fprintf(fout, '        orientation, reference, %s, eye,\n', reference);
fprintf(fout, '        body');

for n = 1:2*nbeam+1,
    fprintf(fout, ',\n');
    fprintf(fout, '                %s + %d', reference, n-1);
end

fprintf(fout, ';\n');
fprintf(fout, '\n');

%% BEAMS

dbeam = dataRebin;
dbeam([1 end],:) = []; %Datos interpolados en en los puntos de integracin
dnode = interp1(zr,data,zn); %Datos interpolados en los nodos

if type == 0
  xel = zeros(2*nbeam+1,1);
  yel = xel;
  tel = xel;
  ti = zeros(2*nbeam);
  cont = 5;
  damp = 'TwrDmp';
else
  %Structural
  xel = - dnode(:,7);
  yel = - dnode(:,8);
  tel = dnode(:,9)*pi/180;
  ti = dbeam(:,9)*pi/180;
  cont = 10;
  damp = 'BldDmp';
  %Aero
  eval = [-1 : 2/(nint-1) : 1];
  name2 = '../Beams/Blade_aero.elm';
  fout2 = fopen(name2, 'w');
  header(fout2); 
end

GJ = dbeam(:,cont);
EA = dbeam(:,cont+1);
EIx = dbeam(:,cont+2); %Edge
EIy = dbeam(:,cont+3); %Flap
GAy = .5*EA; %To be updated with real data
GAx = .1*EA; %To be updated with real data
xsc = xel;
ysc = yel;
x = xsc - xel;
y = ysc - yel;

zpoint = 1;

for b = 1:nbeam
    
    
    fprintf(fout, '# %.3f => %.3f m\n', zn(2*(b - 1) + 1), zn(2*(b - 1) + 3));
    fprintf(fout, 'beam3: %s + %d', reference, b);
    
    if type ==1
        fprintf(fout2, '# %.3f => %.3f m\n', zn(2*(b - 1) + 1), zn(2*(b - 1) + 3));
        fprintf(fout2, 'aerodynamic beam3: %s + %d, %s + %d,\n', reference, b, reference, b);
        fprintf(fout2, '        induced velocity, ROTOR');
    end

    for n = 1:3,
        znode = 2*(b - 1) + n;

        fprintf(fout, ',\n');
        fprintf(fout, '        %s + %d,\n', reference, znode-1);
        fprintf(fout, '        reference, node,\n');
        fprintf(fout, '                %+15.8e, %+15.8e, %+15.8e,\n', xel(znode), yel(znode), 0);
        fprintf(fout, '        orientation, reference, node,\n');
        fprintf(fout, '                1, %+15.8e, %+15.8e, %+15.8e,\n', 0., 0., 1.);
        fprintf(fout, '                3, %+15.8e, %+15.8e, %+15.8e', sin(tel(znode)), cos(tel(znode)), 0.);
        
        if type == 1
            fprintf(fout2, ',\n');
            fprintf(fout2, '        reference, node,\n');
            fprintf(fout2, '                %+15.8e, %+15.8e, %+15.8e,\n', 0., 0., 0.);
            fprintf(fout2, '        reference, node,\n');
            fprintf(fout2, '                1, %+15.8e, %+15.8e, %+15.8e,\n', -sin(tel(znode)), -cos(tel(znode)), 0.);
            fprintf(fout2, '                3, %+15.8e, %+15.8e, %+15.8e', 0., 0., 1.);
        end
        
    end

    for p = 1:2,

        fprintf(fout, ',\n');
%          fprintf(fout, '        from nodes,\n');

        fprintf(fout, '        reference, %s,\n', reference);
        fprintf(fout, '                1, %+15.8e, %+15.8e, %+15.8e,\n', 0., 0., 1.);
        fprintf(fout, '                3, %+15.8e, %+15.8e, %+15.8e,\n', sin(ti(zpoint)), cos(ti(zpoint)), 0.);
        
        fprintf(fout, '        linear viscoelastic generic, sym,\n');
        fprintf(fout,'                %+15.8e, %+15.8e, %+15.8e, %+15.8e, %+15.8e, %+15.8e,\n',...
            EA(zpoint,1), 0., 0., 0., x(zpoint,1)*EA(zpoint,1), -y(zpoint,1)*EA(zpoint,1));
        fprintf(fout, '                                 %+15.8e, %+15.8e, %+15.8e, %+15.8e, %+15.8e,\n',...
            GAx(zpoint,1), 0., 0., 0., 0.);
        fprintf(fout, '                                                  %+15.8e, %+15.8e, %+15.8e, %+15.8e,\n',...
            GAy(zpoint,1), 0., 0., 0.);
        fprintf(fout, '                                                                   %+15.8e, %+15.8e, %+15.8e,\n',...
            GJ(zpoint,1), 0., 0.);
        fprintf(fout, '                                                                                    %+15.8e, %+15.8e,\n',...
            EIx(zpoint,1)+x(zpoint,1)^2*EA(zpoint,1), -x(zpoint,1)*y(zpoint,1)*EA(zpoint,1));
        fprintf(fout, '                                                                                                     %+15.8e,\n',...
            EIy(zpoint,1)+y(zpoint,1)^2*EA(zpoint,1));
        fprintf(fout, '                proportional, %s', damp);
        
        zpoint = zpoint+1;
        
    end
    fprintf(fout, ';\n');
    fprintf(fout, '\n');
    
    %% Aeorydnamic beam
    if type == 1
        
        fprintf(fout2, ',\n');
        
        r = [dnode(2*b-1,1) : (dnode(2*b+1,1)-dnode(2*b-1,1))/(nint-1) : dnode(2*b+1,1)];
        adata = interp1(zr,data(:,end-2:end),r);
        
        for j = 1 : 3
            fprintf(fout2, '        piecewise linear, %d,\n', nint);
           
            for i =1 : nint
                fprintf(fout2, '                %+15.8e, %+15.8e,\n', eval(i), adata(i,j));
            end
            
            if j == 2
                fprintf(fout2, '        piecewise linear, %d,\n', nint);
                for i =1 : nint
                    fprintf(fout2, '                %+15.8e, %+15.8e,\n', eval(i), -0.25*adata(i,j-1));
                end
                adata = adata*pi/180;
            end
        end
        
        fprintf(fout2, '        %d,\n', nint);
        fprintf(fout2, '        c81, multiple, %d,\n', nint-1);
        
        for i=1:nint-1
%             f= [1990 1998 2001 2004 2001 33333]
%             [c index] = min(abs(f-2000))
%             closestValues = f(index) % Finds first one only!
            if i == nint-1
                fprintf(fout2, '                %s, %+15.8e;\n', 'airfoil', eval(i+1));
            else
                fprintf(fout2, '                %s, %+15.8e,\n', 'airfoil', eval(i+1));
            end
        end
    end
    
end
    fclose(fout);
    
    
end








    
    


